@@ -26,7 +26,7 @@ class HomeAssistantCog(commands.Cog):
     @commands.has_role("Shiny")
     async def vacuum(self, context: discord.Interaction, choices: str):
         # print(await self.get_functions())
-        roomba = ha.Vacuum("roomba_pt")
+        roomba = ha.Vacuum()
         roomba_function = getattr(roomba, choices)
         roomba_function()
         await context.response.send_message(f"Vacuum is {choices}ing")
@@ -36,12 +36,12 @@ class HomeAssistantCog(commands.Cog):
     @commands.has_role("Shiny")
     async def arm(self, context: discord.Interaction, choices: str):
         # print(await self.get_functions())
-        testing = ha.Alarm("system")
+        testing = ha.Alarm()
         testing_function = getattr(testing, choices)
         testing_function()
         await context.response.send_message(f"Testing is {choices}ing")
 
-    @app_commands.command(name="tesla")
+    @app_commands.command(name="taylor_swiftly")
     @app_commands.choices(choices=get_functions(ha.Lock))
     @commands.has_role("Shiny")
     async def tesla(self, context: discord.Interaction, choices: str):
