@@ -24,6 +24,11 @@ class HomeAssistant:
         methods = [method for method, _ in inspect.getmembers(cls, predicate=inspect.isfunction) if not method.startswith("__")]
         return methods
 
+    def status(self):
+        """Get input boolean status"""
+
+        return self.client.get_entity(entity_id=self.entity_id).get_state().state
+
 
 class Vacuum(HomeAssistant):
     """Class for Roomba vacuum cleaner"""
@@ -65,13 +70,6 @@ class InputBoolean(HomeAssistant):
         """Toggle input boolean"""
         self.client.get_domain(self.domain).toggle(entity_id=self.entity_id)
 
-    def status(self):
-        """Get input boolean status"""
-
-        return (
-            self.client.get_entity(entity_id=self.entity_id).get_state().state
-        )  #  self.client.get_domain(self.domain). (entity_id=self.entity_id)
-
 
 class Alarm(HomeAssistant):
     """Class for Alarm panel"""
@@ -88,12 +86,6 @@ class Alarm(HomeAssistant):
         """Arm alarm panel"""
         self.client.get_domain(self.domain).alarm_disarm(entity_id=self.entity_id)
 
-    def status(self):
-        """Get alarm status"""
-        alarm = self.client.get_domain(self.domain)
-
-        return self.client.get_domain(self.domain).get_state(entity_id=self.entity_id)
-
 
 class Lock(HomeAssistant):
     """Class for Locks"""
@@ -117,6 +109,6 @@ class Lock(HomeAssistant):
 if __name__ == "__main__":
     testing = InputBoolean("testing")
     print(testing.toggle())
-    print(testing.state())
+    print(testing.status())
     # alarm = Alarm()
     # print(alarm.status())
